Injectable boundary between provider-neutral sessions and FluidAudio.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> - Closes every outstanding driver. Must be idempotent.
-
createBatchAsr(
FluidRecognitionModel model) → Future< FluidBatchAsrDriver> - Creates and loads a batch recognizer.
-
createDiarizer(
FluidDiarizationDriverConfiguration configuration) → Future< FluidDiarizationDriver> - Creates and loads a batch diarizer.
-
createEndOfUtterance(
{required FluidEndOfUtteranceChunk chunk, required Duration debounce}) → Future< FluidEndOfUtteranceDriver> - Creates and loads an end-of-utterance model.
-
createStreamingAsr(
FluidStreamingAsrDriverConfiguration configuration) → Future< FluidStreamingAsrDriver> - Creates and loads a streaming recognizer.
-
createTts(
FluidTtsDriverConfiguration configuration) → Future< FluidTtsDriver> - Creates and loads a synthesis engine.
-
createVad(
{required double threshold, required Duration minimumSilence}) → Future< FluidVadDriver> - Creates and loads a VAD stream.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited